@@ -12,7 +12,7 @@
 #' An R object containing the outcome of a statistical analysis. Currently, the
 #' following objects can be processed: t_test(), bartlett_test(), lm(), aov(),
 #' manova(), cor_test(), lmer() (only for testing random intercep variances),
-#' glm(), coxph(), survreg(), polr(), zeroinfl(), rma(), or named vector objects.
+#' glm(), coxph(), survreg(), polr(), zeroinfl(), rma(), ergm(), or named vector objects.
 #' In the case \code{x} is a named vector, the arguments \code{Sigma} and \code{n}
 #' are also needed. See vignettes for elaborations.
 #' @param hypothesis A character string containing the constrained (informative) hypotheses to
@@ -22,6 +22,10 @@
 #' The default is NULL which will specify equal prior probabilities.
 #' @param complement a logical specifying whether the complement should be added
 #' to the tested hypothesis under \code{hypothesis}.
+#' @param BF.type An integer that specified the type of Bayes factor (or prior) that is used for the test.
+#' Currently, this argument is only used for models of class 'lm' and 't_test',
+#' where \code{BF.type=2} implies an adjusted fractional Bayes factor with a 'fractional prior mean' at the null value (Mulder, 2014),
+#' and \code{BF.type=1} implies a regular fractional Bayes factor (based on O'Hagan (1995)) with a 'fractional prior mean' at the MLE.
 #' @param Sigma An approximate posterior covariance matrix (e.g,. error covariance
 #' matrix) of the parameters of interest. This argument is only required when \code{x}
 #' is a named vector.
@@ -29,6 +33,7 @@
 #' \code{x} and the error covariance matrix \code{Sigma}. This argument is only required when \code{x}
 #' is a named vector.
 #' @param ... Parameters passed to and from other functions.
+#' @usage NULL
 #' @return The output is an object of class \code{BF}. The object has elements:
 #' \itemize{
 #' \item BFtu_exploratory: The Bayes factors of the constrained hypotheses against
@@ -62,9 +67,9 @@
 #' against the unconstrained hypothesis.
 #' \item The sixth column `\code{BF>}' contains the Bayes factor of the order constraints
 #' against the unconstrained hypothesis.
-#' \item The seveth column `\code{BF}' contains the Bayes factor of the constrained hypothesis
+#' \item The seventh column `\code{BF}' contains the Bayes factor of the constrained hypothesis
 #' against the unconstrained hypothesis.
-#' \item The eigth column `\code{BF=}' contains the posterior probabilities of the
+#' \item The eighth column `\code{BF=}' contains the posterior probabilities of the
 #' constrained hypotheses.
 #' }
 #' \item prior: The prior probabilities of the constrained hypotheses in a confirmatory test.
@@ -200,6 +205,6 @@
 #' @export
 #' @useDynLib BFpack, .registration = TRUE
 #'
-BF <- function(x, hypothesis, prior.hyp, complement, Sigma, n, ...) {
+BF <- function(x, hypothesis, prior.hyp, complement, ...) {
   UseMethod("BF", x)
 }
