@@ -2,7 +2,7 @@ set.seed(123)
 #split data frame in two data frame for each group
 memoryHC <- subset(memory,Group=="HC")[,-(4:7)]
 memorySZ <- subset(memory,Group=="SZ")[,-(4:7)]
-cor1 <- cor_test(memoryHC,memorySZ)
+cor1 <- cor_test(memoryHC,memorySZ,iter = 5)
 BF6_cor <- BF(cor1, hypothesis=
     "Del_with_Im_in_g1 > Del_with_Im_in_g2 &
     Del_with_Wmn_in_g1 > Del_with_Wmn_in_g2 &
@@ -14,3 +14,4 @@ test_that("correlation test on cor_test object with two groups correctly evaluat
 )})
 
 
+memoryHC <- rmvnorm(1e4,mean=c(1,2,3))
